@@ -979,7 +979,7 @@ void Rename::updateNameView()
 	    }
 
 	    b=a;
-	    b.append(QString("_TMP"));
+	    b.append(QString("_tmp"));
 	    g.ren[g.getSorted(i)].newName=g.ren[g.getSorted(i)].Prefix+a;
 	    g.ren[g.getSorted(i)].newTmpName=g.ren[g.getSorted(i)].Prefix+b;
 	}
